#[repr(u8)]pub enum NsrS1 {
NSR_S1_0 = 0,
NSR_S1_1 = 1,
}Variants
NSR_S1_0 = 0
The non-secure supervisor read access is disabled for the first slave.
NSR_S1_1 = 1
The non-secure supervisor read access is enabled for the first slave.
Implementations