#[repr(u8)]pub enum NsrS2 {
NSR_S2_0 = 0,
NSR_S2_1 = 1,
}Variants
NSR_S2_0 = 0
The non-secure supervisor read access is disabled for the second slave.
NSR_S2_1 = 1
The non-secure supervisor read access is enabled for the second slave.
Implementations