#[repr(u8)]pub enum NswS2 {
NSW_S2_0 = 0,
NSW_S2_1 = 1,
}Variants
NSW_S2_0 = 0
The non-secure supervisor write access is disabled for the second slave.
NSW_S2_1 = 1
The non-secure supervisor write access is enabled for the second slave.
Implementations