#[repr(u8)]pub enum NurS1 {
NUR_S1_0 = 0,
NUR_S1_1 = 1,
}Variants
NUR_S1_0 = 0
The non-secure user read access is disabled for the first slave.
NUR_S1_1 = 1
The non-secure user read access is enabled for the first slave.
Implementations