#[repr(u8)]pub enum NurS2 {
NUR_S2_0 = 0,
NUR_S2_1 = 1,
}Variants
NUR_S2_0 = 0
The non-secure user read access is disabled for the second slave.
NUR_S2_1 = 1
The non-secure user read access is enabled for the second slave.
Implementations