#[repr(u8)]pub enum SswS2 {
SSW_S2_0 = 0,
SSW_S2_1 = 1,
}Variants
SSW_S2_0 = 0
The secure supervisor write access is disabled for the second slave.
SSW_S2_1 = 1
The secure supervisor write access is enabled for the second slave.
Implementations