#[repr(u8)]pub enum SurS1 {
SUR_S1_0 = 0,
SUR_S1_1 = 1,
}Variants
SUR_S1_0 = 0
The secure user read access is disabled for the first slave.
SUR_S1_1 = 1
The secure user read access is enabled for the first slave.
Implementations